@@ -24,10 +24,10 @@ def evidencegapmap(dataset, x_column, y_column, xy_column=None, bubble_column=No
     # Set the plotting mode for the plots inside a cell
     if xy_column :
         mode = 'nlpmode'
-        xmax = max(map(lambda xy: xy[0], list(dataset[xy_column])))
-        xmin = min(map(lambda xy: xy[0], list(dataset[xy_column])))
-        ymax = max(map(lambda xy: xy[1], list(dataset[xy_column])))
-        ymin = min(map(lambda xy: xy[1], list(dataset[xy_column])))
+        xmax = max(map(lambda xy: float(xy[0]), list(dataset[xy_column])))
+        xmin = min(map(lambda xy: float(xy[0]), list(dataset[xy_column])))
+        ymax = max(map(lambda xy: float(xy[1]), list(dataset[xy_column])))
+        ymin = min(map(lambda xy: float(xy[1]), list(dataset[xy_column])))
         xshift = (xmax + xmin)/2
         yshift = (ymax + ymin)/2
         xy_scale= max(xmax-xmin, ymax-ymin)
